@@ -120,7 +120,7 @@
          "PSFILE" "PUSH" "PUSH-FUNCS" "PUSH-VARS" "PUSH-OMIT-CONTEXT" "REM" "RETURN"
          "RUN" "SATISFY" "SCAN" "SCANFROM" "SCHED" "SECOND" "SET"
          "SKIP" "SPECIAL" "SYSINCLUDE" "TAG" "THIRD" "THROUGH" "TODO"
-         "TRANSLATE" "TRANS" "UNSET" "UNTIL" "WARN")
+         "TRANSLATE" "TRANS" "TZ" "UNSET" "UNTIL" "WARN")
    #'(lambda (a b) (> (length a) (length b)))))
 
 
@@ -179,9 +179,9 @@
          "realtoday" "rows" "sgn" "shell" "shellescape" "slide" "soleq"
          "stdout" "strlen" "substr" "sunrise" "sunset" "time" "timepart"
          "timezone" "today" "trig" "trigback" "trigbase" "trigcompletethrough" "trigdate" "trigdatetime"
-         "trigdelta" "trigduration" "trigeventduration" "trigeventstart"
+         "trigdelta" "trigduration" "trigeventduration" "trigeventstart" "trigeventstarttz"
          "trigfrom" "trigger" "triginfo" "trigistodo" "trigmaxoverdue" "trigpriority" "trigrep"
-         "trigscanfrom" "trigtags" "trigtime" "trigtimedelta" "trigtimerep"
+         "trigscanfrom" "trigtags" "trigtime" "trigtimedelta" "trigtimerep" "trigtimetz" "trigtz"
          "triguntil" "trigvalid" "typeof" "tzconvert" "upper" "utctolocal"
          "value" "version" "weekno" "wkday" "wkdaynum" "year"
          )
