@@ -132,6 +132,8 @@
 #define E_COMPLETE_WITHOUT_TODO 108
 #define E_MAX_OVERDUE_TWICE 109
 #define E_MAX_OVERDUE_WITHOUT_TODO 110
+#define E_TZ_SPECIFIED_TWICE 111
+#define E_TZ_NO_AT          112
 
 #ifdef MK_GLOBALS
 #undef EXTERN
@@ -261,6 +263,8 @@ EXTERN char *ErrMsg[]
 /* E_COMPLETE_WITHOUT_TODO */ "COMPLETE-THROUGH specified without TODO",
 /* E_MAX_OVERDUE_TWICE */ "MAX-OVERDUE specified twice",
 /* E_MAX_OVERDUE_WITHOUT_TODO */ "MAX-OVERDUE specified without TODO",
+/* E_TZ_SPECIFIED_TWICE */ "TZ specified twice",
+/* E_TZ_NO_AT */           "TZ specified for non-timed reminder",
 }
 #endif /* MK_GLOBALS */
 ;
