@@ -177,8 +177,25 @@ void InitRemind(int argc, char const *argv[])
     int dse;
     int ttyfd;
 
+    /* Make sure remind is not installed set-uid or set-gid */
+    if (getgid() != getegid() ||
+        getuid() != geteuid()) {
+        fprintf(ErrFp, "\nRemind should not be installed set-uid or set-gid.\nCHECK YOUR SYSTEM SECURITY.\n");
+        exit(EXIT_FAILURE);
+    }
+
     dse = NO_DATE;
 
+    /* Initialize local time zone */
+    LocalTimeZone = getenv("TZ");
+    if (LocalTimeZone) {
+        LocalTimeZone = StrDup(LocalTimeZone);
+        if (!LocalTimeZone) {
+            fprintf(stderr, "Out of memory!\n");
+            exit(1);
+        }
+    }
+
     /* Initialize variable hash table */
     InitVars();
 
@@ -203,13 +220,6 @@ void InitRemind(int argc, char const *argv[])
 
     InitDedupeTable();
 
-    /* Make sure remind is not installed set-uid or set-gid */
-    if (getgid() != getegid() ||
-        getuid() != geteuid()) {
-        fprintf(ErrFp, "\nRemind should not be installed set-uid or set-gid.\nCHECK YOUR SYSTEM SECURITY.\n");
-        exit(EXIT_FAILURE);
-    }
-
     y = NO_YR;
     m = NO_MON;
     d = NO_DAY;
@@ -221,7 +231,9 @@ void InitRemind(int argc, char const *argv[])
         fprintf(ErrFp, "\n");
         exit(EXIT_FAILURE);
     }
+    LocalSysTime = SystemTime(0);
     DSEToday = RealToday;
+    LocalDSEToday = DSEToday;
     FromDSE(DSEToday, &CurYear, &CurMon, &CurDay);
 
     /* Initialize Latitude and Longitude */
@@ -646,6 +658,7 @@ void InitRemind(int argc, char const *argv[])
                     case 'q': case 'Q': DebugFlag |= DB_TRANSLATE;   break;
                     case 'n': case 'N': DebugFlag |= DB_NONCONST;    break;
                     case 'u': case 'U': DebugFlag |= DB_UNUSED_VARS; break;
+                    case 'z': case 'Z': DebugFlag |= DB_SWITCH_ZONE; break;
                     default:
                         fprintf(ErrFp, GetErr(M_BAD_DB_FLAG), *(arg-1));
                         fprintf(ErrFp, "\n");
@@ -711,6 +724,7 @@ void InitRemind(int argc, char const *argv[])
                 if (SysTime != -1L) Usage();
                 else {
                     SysTime = (long) tok.val * 60L;
+                    LocalSysTime = SysTime;
                     DontQueue = 1;
                     Daemon = 0;
                 }
@@ -720,6 +734,7 @@ void InitRemind(int argc, char const *argv[])
                 if (SysTime != -1L) Usage();
                 if (m != NO_MON || d != NO_DAY || y != NO_YR || dse != NO_DATE) Usage();
                 SysTime = (tok.val % MINUTES_PER_DAY) * 60;
+                LocalSysTime = SysTime;
                 DontQueue = 1;
                 Daemon = 0;
                 dse = tok.val / MINUTES_PER_DAY;
@@ -790,6 +805,7 @@ void InitRemind(int argc, char const *argv[])
                 fprintf(ErrFp, "%s", BadDate);
                 Usage();
             }
+            LocalDSEToday = DSEToday;
             CurYear = y;
             CurMon = m;
             CurDay = d;
@@ -1144,6 +1160,7 @@ ProcessLongOption(char const *arg)
         /* Update RealToday because of TestMode */
         RealToday = SystemDate(&CurYear, &CurMon, &CurDay);
         DSEToday = RealToday;
+        LocalDSEToday = DSEToday;
         FromDSE(DSEToday, &CurYear, &CurMon, &CurDay);
 
         return;
