@@ -153,6 +153,7 @@ int main(int argc, char *argv[])
 
     DBufInit(&(LastTrigger.tags));
     LastTrigger.infos = NULL;
+    LastTrigger.tz = NULL;
     ClearLastTriggers();
 
     atexit(exitfunc);
@@ -1290,7 +1291,9 @@ int DoIfTrig(ParsePtr p)
     } else {
         if ( (r=ParseRem(p, &trig, &tim)) ) return r;
         if (trig.typ != NO_TYPE) return E_PARSE_ERR;
+        EnterTimezone(trig.tz);
         dse = ComputeTrigger(get_scanfrom(&trig), &trig, &tim, &r, 1);
+        ExitTimezone(trig.tz);
         if (r) {
             if (r != E_CANT_TRIG || !trig.maybe_uncomputable) {
                 if (!Hush || r != E_RUN_DISABLED) {
@@ -1299,6 +1302,9 @@ int DoIfTrig(ParsePtr p)
             }
             push_if(0, 0);
         } else {
+            if (dse >= 0) {
+                dse = AdjustTriggerForTimeZone(&trig, dse, &tim);
+            }
             if (ShouldTriggerReminder(&trig, &tim, dse, &err)) {
                 push_if(1, 0);
             } else {
@@ -1439,6 +1445,11 @@ static int DoDebug(ParsePtr p)
             if (val) DebugFlag |= DB_UNUSED_VARS;
             else     DebugFlag &= ~DB_UNUSED_VARS;
             break;
+        case 'z':
+        case 'Z':
+            if (val) DebugFlag |= DB_SWITCH_ZONE;
+            else     DebugFlag &= ~DB_SWITCH_ZONE;
+            break;
         default:
             Wprint(GetErr(M_BAD_DB_FLAG), ch);
             break;
@@ -2039,6 +2050,10 @@ FreeTrig(Trigger *t)
     if (t->infos) {
         FreeTrigInfoChain(t->infos);
     }
+    if (t->tz) {
+        free( (void *) t->tz);
+    }
+    t->tz = NULL;
     t->infos = NULL;
 }
 
@@ -2069,7 +2084,9 @@ ClearLastTriggers(void)
     LastTrigger.complete_through = NO_DATE;
     LastTrigger.max_overdue = -1;
     FreeTrig(&LastTrigger);
+
     LastTimeTrig.ttime = NO_TIME;
+    LastTimeTrig.ttime_orig = NO_TIME;
     LastTimeTrig.delta = NO_DELTA;
     LastTimeTrig.rep   = NO_REP;
     LastTimeTrig.duration = NO_TIME;
@@ -2098,6 +2115,9 @@ SaveLastTrigger(Trigger const *t)
     LastTrigger.infos = NULL;
     DBufInit(&(LastTrigger.tags));
 
+    if (LastTrigger.tz) {
+        LastTrigger.tz = StrDup(LastTrigger.tz);
+    }
     DBufPuts(&(LastTrigger.tags), DBufValue(&(t->tags)));
     TrigInfo *cur = t->infos;
     while(cur) {
