@@ -296,3 +296,8 @@ void remove_trailing_newlines(DynamicBuffer *buf);
 void set_cloexec(int fd);
 int system_to_stderr(char const *cmd);
 int system1(char const *cmd);
+int tz_set_tz (char const *tz);
+int tz_convert(int year, int month, int day, int hour, int minute, char const *src_tz, char const *tgt_tz, struct tm *tm);
+int AdjustTriggerForTimeZone(Trigger *trig, int dse, TimeTrig *tim);
+void EnterTimezone(char const *tz);
+void ExitTimezone(char const *tz);
