@@ -453,6 +453,7 @@ AdjustTriggerForDuration(int today, int r, Trigger *trig, TimeTrig *tim, int sav
     /* If we have an AT, save the original event start */
     if (tim->ttime != NO_TIME) {
         trig->eventstart = MINUTES_PER_DAY * r + tim->ttime;
+        trig->eventstart_orig = trig->eventstart;
         if (tim->duration != NO_TIME) {
             trig->eventduration = tim->duration;
         }
@@ -515,6 +516,7 @@ int ComputeTrigger(int today, Trigger *trig, TimeTrig *tim,
     if (r == today) {
         if (tim->ttime != NO_TIME) {
             trig->eventstart = MINUTES_PER_DAY * r + tim->ttime;
+            trig->eventstart_orig = trig->eventstart;
             if (tim->duration != NO_TIME) {
                 trig->eventduration = tim->duration;
             }
@@ -613,6 +615,21 @@ int ComputeTriggerNoAdjustDuration(int today, Trigger *trig, TimeTrig const *tim
             omit = 0;
         }
 
+        /** FIXME: If a timed reminder moves to yesterday because of a time
+            zone adjustment, try again! */
+
+        if (trig->tz) {
+            TimeTrig copy = *tim;
+            int new_result;
+            ExitTimezone(trig->tz);
+            new_result = AdjustTriggerForTimeZone(trig, result, &copy);
+            EnterTimezone(trig->tz);
+            if (new_result + duration_days < today) {
+                nextstart = start+1;
+                start = nextstart;
+                continue;
+            }
+        }
         /** FIXME: Fix bad interaction with SATISFY... need to rethink!!! */
         if (result+duration_days >= today &&
             (trig->skip != SKIP_SKIP || !omit)) {
